﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Data.SQLite;
using System.Linq;
using System.Web;
using EmptyWebApp.Modelos;

namespace EmptyWebApp
{
    /// <summary>
    /// Logica de conexion de deptos.
    /// </summary>
    public class DepartamentoBL
    {

        private BaseDeDatos db;

        public DepartamentoBL()
        {
            db = new BaseDeDatos();
        }

        /// <summary>
        /// Obtiene todos los departementos del sistema
        /// </summary>
        /// <returns>retorna un set datos.</returns>
        public List<Departamento> ObtenerTodos()
        {
            return db.Departamentos.ToList();
        }

        private void ValidarNombre(string nombre)
        {
            if (string.IsNullOrWhiteSpace(nombre))
            {
                throw new ArgumentNullException("nombre");
            }

            if (nombre.Length > 200)
            {
                throw new ApplicationException("El nombre no puede superar los 200 caracteres de longitud");
            }
        }

        public void Crear(string nombre)
        {
            ValidarNombre(nombre);

            var depto = new Departamento();
            depto.Nombre = nombre;
            db.Departamentos.Add(depto);
            db.SaveChanges();

        }

        public void Editar(int id, string nombre)
        {
            ValidarNombre(nombre);
            var depto = ObtenerUnico(id);
            depto.Nombre = nombre;
            db.SaveChanges();
        }

        public void Eliminar(int id)
        {
            var depto = ObtenerUnico(id);
            db.Departamentos.Remove(depto);
            db.SaveChanges();
        }

        public Departamento ObtenerUnico(int id)
        {
            return db.Departamentos.Find(id);
        }

    }
}